@@ -1,3 +1,4 @@
+#include <R_ext/Print.h>
 #include "simple_re.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -6,33 +7,33 @@ int main(int argc, char** argv){
 	
 	simple_re* re = simple_re_compile("^(\\S)(.)+",  "UTF-8");
 
-{}//	printf("Compilation finished. \n");	
+	Rprintf("Compilation finished. \n");	
 
 //	const char* string = "こんにちは World";
 	const char* string = "Hello World";
 	simple_re* ptr_to_store;
 	int result = simple_re_match( re , string , &ptr_to_store);
-{}//	printf("Matching finished. \n");
+	Rprintf("Matching finished. \n");
 
 	int num;
 	char* str;
 	int idx;
 	if(result == 1 ){
-{}//		printf("success match found. \n");
-{}//		printf("Showing ... \n");
+		Rprintf("success match found. \n");
+		Rprintf("Showing ... \n");
 		
 		num = simple_re_matched_group_num(ptr_to_store);
 		for(idx = 0; idx < num ; ++idx){
 			str = simple_re_matched_str( ptr_to_store , idx );
 			if(idx == 0){
-{}//				printf("Whole Matched : %s \n", str );
+				Rprintf("Whole Matched : %s \n", str );
 			} else {
-{}//				printf("Matched Group %d : %s \n", idx, str );
+				Rprintf("Matched Group %d : %s \n", idx, str );
 			}
 			free(str);
 		}
 	}else{
-{}//		printf("No match. %d \n", result);
+		Rprintf("No match. %d \n", result);
 	}
 	simple_re_free(re);
 }
