@@ -19,6 +19,7 @@ var_elem* var_hash_insert (var_hash** , var_elem* );
 var_elem* var_hash_find (var_hash** , char* );
 int var_hash_size( var_hash** );
 char** var_hash_names( var_hash** );
-int var_hash_free( var_hash** );
+void var_hash_names_free( char** hash_names, int size );
+void var_hash_free( var_hash** );
 
 #endif // VAR_HASH_H
