@@ -8,11 +8,14 @@
 #include "ptr_table.h"
 #include "simple_re.h"
 #include "helper.h"
+#include "vm_error.h"
 
 int vm_stack_assign_numval_to_ptr_dbl_record(ptr_record* left_record, stack_item* rvalue);
 int vm_stack_assign_numval_to_ptr_int_record(ptr_record* left_record, stack_item* rvalue);
 int vm_stack_assign_temp_str_to_record(ptr_record* left_record, stack_item* rvalue);
 int vm_stack_assign_copy_str_to_record(ptr_record* left_record, stack_item* rvalue);
+int vm_stack_assign_temp_rexp_to_record(ptr_record* left_record, stack_item* rvalue);
+int vm_stack_assign_copy_rexp_to_record(ptr_record* left_record, stack_item* rvalue);
 
 // Needed?
 int vm_stack_convert_str_item_into_void(ptr_record* left_record, stack_item* rvalue);
@@ -28,19 +31,15 @@ vm_stack_store_val(vm_stack* vmstack)
 	
 	// lvalue should point to heap memory to store objects or values, b/c they should be returned to library user.
 	// If they are not stored on heap, there are possibilities that they are automatically destroyed.
-	ptr_record* left_record;
-	if( (lvalue->type != NULL_ITEM) && (lvalue->type != PP_IVAL ) && (lvalue->type != PP_DVAL ) && (lvalue->type != PP_STR )){
-		Rprintf("ERROR: lvalue should be pointer to pointer, such as PP_IVAL, PP_DVAL or PP_STR, or NULL_ITEM.\n");
+	ptr_record* left_record = NULL;
+	if( (lvalue->type != NULL_ITEM) && (lvalue->type != PP_IVAL ) && (lvalue->type != PP_DVAL ) && (lvalue->type != PP_STR ) && (lvalue->type != PP_REXP )){
+		Rprintf("ERROR: lvalue should be pointer to pointer, such as PP_IVAL, PP_DVAL, PP_STR or PP_REXP, or NULL_ITEM.\n");
+		vm_error_raise(vmstack);
+		return 0;
 	} else {
 		left_record = (ptr_record*)lvalue->p_record;
 	}
 
-	double tmp_dbl;
-	int tmp_int; 
-	char* tmp_str;
-	string_object* tmp_s_str;
-
-
 	if(lvalue->type == NULL_ITEM){ // Unknown variables
 		// ------------------------------
 		// Unknown and undefined lvalue
@@ -109,6 +108,7 @@ vm_stack_store_val(vm_stack* vmstack)
 				left_record->gc = GC_YES;
 			}else{
 				Rprintf("ERROR: Only IVAL, DVAL, PP_STR or PP_REXP can be rvalue for assignment operator.\n");
+				vm_error_raise(vmstack);
             }
 
 		// ------------------------------
@@ -118,23 +118,48 @@ vm_stack_store_val(vm_stack* vmstack)
 		// Unknown but defined variable as PTR_INT
 		}else if(left_record->type == PTR_INT){ 
 			DEBUG_PRINT("This lvalue is an originally unknown but is now defined variable, PTR_INT.\n");
-			vm_stack_assign_numval_to_ptr_int_record(left_record, rvalue);
+			if( vm_stack_assign_numval_to_ptr_int_record(left_record, rvalue) != 1){
+				vm_error_raise(vmstack);
+			}
 		// Unknown but defined variable as PTR_DBL
 		}else if(left_record->type == PTR_DBL){
 			DEBUG_PRINT("This lvalue is an originally unknown but is now defined variable, PTR_DBL.\n");
-			vm_stack_assign_numval_to_ptr_dbl_record(left_record, rvalue);
+			if( vm_stack_assign_numval_to_ptr_dbl_record(left_record, rvalue) != 1){
+				vm_error_raise(vmstack);
+			}
 		// Unknown but defined variable as PTR_STR
 		}else if(left_record->type == PTR_STR){
 			if(rvalue->type == PP_STR){
 				ptr_record_free_gc_required_memory( left_record );
 				if( vm_stack_item_is_temp(rvalue) ){ // If rvalue is temporary, use the object.
-					vm_stack_assign_temp_str_to_record(left_record, rvalue);
-				}else{  // If rvalue is not tempoary, create a new string and manage it 
-					vm_stack_assign_copy_str_to_record(left_record, rvalue);					
+					if( vm_stack_assign_temp_str_to_record(left_record, rvalue) != 1){
+						vm_error_raise(vmstack);
+					}
+				}else{  // If rvalue is not tempoary, create a new string and manage it
+					if( vm_stack_assign_copy_str_to_record(left_record, rvalue) != 1 ){
+						vm_error_raise(vmstack);
+					} 
 				}
-				left_record->gc = left_record->gc; // No change.
 			}else {
 				Rprintf("ERROR: Object other than PP_STR is trying to be assigned to PTR_STR.\n");
+				vm_error_raise(vmstack);
+			}
+		// Unknown but defined variable as PTR_REXP
+		}else if(left_record->type == PTR_REXP){
+			if(rvalue->type == PP_REXP){
+				ptr_record_free_gc_required_memory( left_record );
+				if( vm_stack_item_is_temp(rvalue) ){ // If rvalue is temporary, use the object.
+					if( vm_stack_assign_temp_rexp_to_record(left_record, rvalue) != 1){
+						vm_error_raise(vmstack);
+					}
+				}else{  // If rvalue is not tempoary, create a new regular expression and manage it
+					if( vm_stack_assign_copy_rexp_to_record(left_record, rvalue) != 1 ){
+						vm_error_raise(vmstack);
+					} 
+				}
+			}else {
+				Rprintf("ERROR: Object other than PP_REXP is trying to be assigned to PTR_REXP.\n");
+				vm_error_raise(vmstack);
 			}
 		}
 
@@ -146,33 +171,67 @@ vm_stack_store_val(vm_stack* vmstack)
 	}else if(lvalue->type == PP_IVAL){
 		if(left_record->type != PTR_INT){
 			Rprintf("ERROR: ptr record should be PTR_INT. This branch should never be executed. \n");
+			vm_error_raise(vmstack);
 		}else{
-			vm_stack_assign_numval_to_ptr_int_record(left_record, rvalue);
+			if( vm_stack_assign_numval_to_ptr_int_record(left_record, rvalue) != 1){
+				vm_error_raise(vmstack);
+			}
 		}
 
 	// as PP_DVAL
 	}else if(lvalue->type == PP_DVAL){
 		if(left_record->type != PTR_DBL){
 			Rprintf("ERROR: ptr record should be PTR_DBL. This branch should never be executed. \n");
+			vm_error_raise(vmstack);
 		}else{
-			vm_stack_assign_numval_to_ptr_dbl_record(left_record, rvalue);
+			if( vm_stack_assign_numval_to_ptr_dbl_record(left_record, rvalue) != 1){
+				vm_error_raise(vmstack);
+			}
 		}
 
 	// as PP_STR
 	}else if(lvalue->type == PP_STR){
 		if(left_record->type != PTR_STR){
 			Rprintf("ERROR: ptr record should be PTR_STR. This branch should never be executed. \n");
+			vm_error_raise(vmstack);
 		}else{
 			if(rvalue->type == PP_STR){
 				ptr_record_free_gc_required_memory( left_record );
 				if( vm_stack_item_is_temp(rvalue) ){ // If rvalue is temporary, use the object.
-					vm_stack_assign_temp_str_to_record(left_record, rvalue);
+					if( vm_stack_assign_temp_str_to_record(left_record, rvalue) != 1){
+						vm_error_raise(vmstack);
+					}
 				}else{  // If rvalue is not tempoary, create a new string and manage it 
-					vm_stack_assign_copy_str_to_record(left_record, rvalue);					
+					if( vm_stack_assign_copy_str_to_record(left_record, rvalue) != 1){
+						vm_error_raise(vmstack);
+					}				
 				}
-				left_record->gc = left_record->gc; // No change.
 			}else {
 				Rprintf("ERROR: Object other than PP_STR is trying to be assigned to PTR_STR.\n");
+				vm_error_raise(vmstack);
+			}
+		}
+
+	// as PP_REXP
+	}else if(lvalue->type == PP_REXP){
+		if(left_record->type != PTR_REXP){
+			Rprintf("ERROR: ptr record should be PTR_REXP. This branch should never be executed. \n");
+			vm_error_raise(vmstack);
+		}else{
+			if(rvalue->type == PP_REXP){
+				ptr_record_free_gc_required_memory( left_record );
+				if( vm_stack_item_is_temp(rvalue) ){ // If rvalue is temporary, use the object.
+					if( vm_stack_assign_temp_rexp_to_record(left_record, rvalue) != 1){
+						vm_error_raise(vmstack);
+					}
+				}else{  // If rvalue is not tempoary, create a new regular expression and manage it
+					if( vm_stack_assign_copy_rexp_to_record(left_record, rvalue) != 1){
+						vm_error_raise(vmstack);
+					}
+				}
+			}else {
+				Rprintf("ERROR: Object other than PP_REXP is trying to be assigned to PTR_REXP.\n");
+				vm_error_raise(vmstack);
 			}
 		}
 	}
@@ -196,7 +255,7 @@ vm_stack_assign_numval_to_ptr_dbl_record(ptr_record* left_record, stack_item* rv
 				left_record->gc = left_record->gc; // This heap area is usually prepared by library user.
 			}else {
 				Rprintf("ERROR: Object other than IVAL an DVAL is trying to be assigned to PTR_DBL.\n");
-				return -1;
+				return 0;
 			}
 			return 1;
 }
@@ -217,7 +276,7 @@ vm_stack_assign_numval_to_ptr_int_record(ptr_record* left_record, stack_item* rv
 				left_record->gc = left_record->gc; // This heap area is usually prepared by library user.
 			}else {
 				Rprintf("ERROR: Object other than IVAL an DVAL is trying to be assigned to PTR_INT.\n");
-				return -1;
+				return 0;
 			}
 			return 1;
 }
@@ -226,6 +285,7 @@ int
 vm_stack_assign_temp_str_to_record(ptr_record* left_record, stack_item* rvalue)
 {
 	left_record->address = (void*) *(rvalue->pp_str);
+	left_record->gc = GC_YES;
 	free(rvalue->pp_str);
 	rvalue->pp_str = NULL;
 	rvalue->type = VOID_ITEM;
@@ -236,6 +296,26 @@ int
 vm_stack_assign_copy_str_to_record(ptr_record* left_record, stack_item* rvalue)
 {
 	left_record->address = (void*) string_new(string_read((string_object*) *(rvalue->pp_str)));
+	left_record->gc = GC_YES;
+	return 1;
+}
+
+int
+vm_stack_assign_temp_rexp_to_record(ptr_record* left_record, stack_item* rvalue)
+{
+	left_record->address = (void*) *(rvalue->pp_rexp);
+	left_record->gc = GC_YES;
+	free(rvalue->pp_rexp);
+	rvalue->pp_rexp = NULL;
+	rvalue->type = VOID_ITEM;
+	return 1;
+}
+
+int
+vm_stack_assign_copy_rexp_to_record(ptr_record* left_record, stack_item* rvalue)
+{
+	left_record->address = (simple_re*) simple_re_compile( (*(rvalue->pp_rexp))->pattern , (*(rvalue->pp_rexp))->encoding );
+	left_record->gc = GC_YES;
 	return 1;
 }
 
